@@ -59,7 +59,10 @@ fn test_project_dev() {
     LEPTOS_JS_MINIFY=false \
     LEPTOS_HASH_FILES=true \
     LEPTOS_HASH_FILE_NAME=hash.txt \
-    LEPTOS_WATCH=true";
+    LEPTOS_WATCH=true \
+    SERVER_FN_PREFIX=/custom/prefix \
+    DISABLE_SERVER_FN_HASH=true \
+    SERVER_FN_MOD_PATH=true";
     assert_eq!(ENV_REF, envs);
 
     assert_snapshot!(cargo, @"cargo build --package=example --bin=example --no-default-features --features=ssr");
@@ -107,7 +110,10 @@ fn test_workspace_project1() {
     LEPTOS_BIN_DIR=project1\\server \
     LEPTOS_JS_MINIFY=false \
     LEPTOS_HASH_FILES=false \
-    LEPTOS_WATCH=true"
+    LEPTOS_WATCH=true \
+    SERVER_FN_PREFIX=/custom/prefix \
+    DISABLE_SERVER_FN_HASH=true \
+    SERVER_FN_MOD_PATH=true"
     } else {
         "\
     LEPTOS_OUTPUT_NAME=project1 \
@@ -119,7 +125,10 @@ fn test_workspace_project1() {
     LEPTOS_BIN_DIR=project1/server \
     LEPTOS_JS_MINIFY=false \
     LEPTOS_HASH_FILES=false \
-    LEPTOS_WATCH=true"
+    LEPTOS_WATCH=true \
+    SERVER_FN_PREFIX=/custom/prefix \
+    DISABLE_SERVER_FN_HASH=true \
+    SERVER_FN_MOD_PATH=true"
     };
 
     let cli = dev_opts();
