@@ -130,7 +130,7 @@ impl Project {
                 watch_additional_files,
                 hash_file,
                 hash_files: config.hash_files,
-                js_minify: cli.release && cli.js_minify && config.js_minify,
+                js_minify: cli.release && (cli.js_minify || config.js_minify),
                 server_fn_prefix: config.server_fn_prefix,
                 disable_server_fn_hash: config.disable_server_fn_hash,
                 server_fn_mod_path: config.server_fn_mod_path,
@@ -167,16 +167,19 @@ impl Project {
             vec.push(("LEPTOS_HASH_FILE_NAME", self.hash_file.rel.to_string()));
         }
         if self.watch {
-            vec.push(("LEPTOS_WATCH", true.to_string()))
+            vec.push(("LEPTOS_WATCH", self.watch.to_string()))
         }
         if let Some(prefix) = self.server_fn_prefix.as_ref() {
             vec.push(("SERVER_FN_PREFIX", prefix.clone()));
         }
         if self.disable_server_fn_hash {
-            vec.push(("DISABLE_SERVER_FN_HASH", true.to_string()));
+            vec.push((
+                "DISABLE_SERVER_FN_HASH",
+                self.disable_server_fn_hash.to_string(),
+            ));
         }
         if self.server_fn_mod_path {
-            vec.push(("SERVER_FN_MOD_PATH", true.to_string()));
+            vec.push(("SERVER_FN_MOD_PATH", self.server_fn_mod_path.to_string()));
         }
         vec
     }
