@@ -32,9 +32,7 @@ pub struct ExeMeta {
     manual: String,
 }
 
-lazy_static::lazy_static! {
-    static ref ON_STARTUP_DEBUG_ONCE: Once = Once::new();
-}
+static ON_STARTUP_DEBUG_ONCE: Once = Once::new();
 
 impl ExeMeta {
     #[allow(clippy::wrong_self_convention)]
@@ -285,14 +283,9 @@ fn normalize_version(ver_string: &str) -> Option<Version> {
         })
 }
 
-// fallback to this crate until rust stable includes async traits
-// https://github.com/dtolnay/async-trait
-use async_trait::async_trait;
-
 struct CommandTailwind;
 struct CommandSass;
 
-#[async_trait]
 impl Command for CommandTailwind {
     fn name(&self) -> &'static str {
         "tailwindcss"
@@ -394,7 +387,7 @@ impl Command for CommandTailwind {
         "Try manually installing tailwindcss: https://tailwindcss.com/docs/installation".to_string()
     }
 }
-#[async_trait]
+
 impl Command for CommandSass {
     fn name(&self) -> &'static str {
         "sass"
@@ -421,15 +414,15 @@ impl Command for CommandSass {
             match target_arch {
                 "x86_64" => {
                     format!(
-                    "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-x64.tar.gz",
-                    self.github_owner(), self.github_repo(), version, version
-                )
+                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-x64.tar.gz",
+                        self.github_owner(), self.github_repo(), version, version
+                    )
                 }
                 "aarch64" => {
                     format!(
-                    "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-arm64.tar.gz"
-                    , self.github_owner(), self.github_repo(), version, version
-                )
+                        "https://github.com/{}/{}/releases/download/{}/dart-sass-{}-linux-arm64.tar.gz"
+                        , self.github_owner(), self.github_repo(), version, version
+                    )
                 }
                 _ => bail!("No sass tar binary found for linux-musl {target_arch}"),
             }
@@ -438,21 +431,21 @@ impl Command for CommandSass {
                 // note the different github_owner
                 ("windows", "x86_64") => {
                     format!(
-                    "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-windows-x64.zip",
-                    self.github_repo(), version, version
-                )
+                        "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-windows-x64.zip",
+                        self.github_repo(), version, version
+                    )
                 }
                 ("macos" | "linux", "x86_64") => {
                     format!(
-                    "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-{}-x64.tar.gz",
-                    self.github_repo(), version, version, target_os
-                )
+                        "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-{}-x64.tar.gz",
+                        self.github_repo(), version, version, target_os
+                    )
                 }
                 ("macos" | "linux", "aarch64") => {
                     format!(
-                    "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-{}-arm64.tar.gz",
-                    self.github_repo(), version, version, target_os
-                )
+                        "https://github.com/sass/{}/releases/download/{}/dart-sass-{}-{}-arm64.tar.gz",
+                        self.github_repo(), version, version, target_os
+                    )
                 }
                 _ => bail!("No sass tar binary found for {target_os} {target_arch}"),
             }
@@ -475,12 +468,11 @@ impl Command for CommandSass {
         "Try manually installing sass: https://sass-lang.com/install".to_string()
     }
 }
-#[async_trait]
+
 /// Template trait, implementors should only fill in
 /// the command-specific logic. Handles caching, latest
 /// version checking against the GitHub API and env var
 /// version override for a given command.
-#[async_trait]
 trait Command {
     fn name(&self) -> &'static str;
     fn version(&self) -> Cow<'_, str>;
